/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2014 Frederik Heber. All rights reserved.
 *
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * SaturatedBondStub.cpp
 *
 *  Created on: Jul 28, 2014
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

//#include "CodePatterns/MemDebug.hpp"

#include "Fragmentation/Exporters/SaturatedBond.hpp"

#include "Atom/atom.hpp"

SaturatedBond::SaturatedBond(
    const bond &_bond,
    const atom& _remaining) :
    saturated_bond(_bond),
    saturated_atom(_remaining)
{
  switch (_remaining.getId()) {
  case 0:
     BondVector = Vector(0.,0.,0.);
     break;
  case 1:
     BondVector = Vector(1.,0.,0.);
     break;
  case 2:
     BondVector = Vector(-1.,0.,0.);
     break;
  case 3:
     BondVector = Vector(0.,1.,0.);
     break;
  case 4:
     BondVector = Vector(0.,-1.,0.);
     break;
  }
  vector_a.Zero();
  vector_b.Zero();
}

std::vector<Vector> SaturatedBond::getPositions() const
{
  std::vector<Vector> positions;
  positions.push_back(BondVector);
  return positions;
}
